@@ -4,7 +4,7 @@ from sqlbean.db.query import Query, escape
 from sqlbean.db.mc_connection import mc
 from marshal import dumps, loads
 from sqlbean.metamodel import cache, lower_name, ModelBase
-
+from array import array
 class McModel(object):
 
     __metaclass__ = ModelBase
@@ -43,7 +43,8 @@ class McModel(object):
 
     @classmethod
     def mc_get_multi(cls, id_list):
-        id_list = tuple(id_list)
+        if type(id_list) not in (array,list,tuple,dict):
+            id_list = tuple(id_list)
         mc_key = cls.Meta.mc_key
         result = mc.get_multi([mc_key%i for i in id_list])
         r = {}
@@ -106,7 +107,8 @@ class McModel(object):
                 if dc_value is None:
                     self._changed.add(name)
                 else:
-                    value = type(dc_value)(value)
+                    if value is not None:
+                        value = type(dc_value)(value)
                     if dc_value != value:
                         self._changed.add(name)
         dc[name] = value
